@@ -1,6 +1,7 @@
 require 'database_cleaner/mongoid/base'
 require 'database_cleaner/generic/truncation'
 require 'database_cleaner/mongo/truncation_mixin'
+require 'database_cleaner/mongo2/truncation_mixin'
 require 'database_cleaner/moped/truncation_base'
 require 'mongoid/version'
 
@@ -20,7 +21,7 @@ module DatabaseCleaner
           ::Mongoid.database
         end
 
-      else
+      elsif ::Mongoid::VERSION < '5'
 
         include ::DatabaseCleaner::Moped::TruncationBase
 
@@ -30,8 +31,19 @@ module DatabaseCleaner
           ::Mongoid.default_session
         end
 
-      end
+        def database
+          if not(@db.nil? or @db == :default)
+            ::Mongoid.databases[@db]
+          else
+            ::Mongoid.database
+          end
+        end
 
+      else
+
+        include ::DatabaseCleaner::Mongo2::TruncationMixin
+
+      end
     end
   end
 end
